% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/spikein.normalization.R
\name{spikein.normalization}
\alias{spikein.normalization}
\title{function to estimate normalization parameters based on spike-in counts
with GLM using offset length, seq depth per sample and cross-contamination control AND a spike-specific parameter to control for e.g.sequence bias}
\usage{
spikein.normalization(counts, spikeins = rownames(counts), spikein.lengths,
  spikein.labeling, samples = colnames(counts), conditions.labeling,
  paired = TRUE, debug = FALSE)
}
\arguments{
\item{counts}{matrix with counts for each spike (rows) and each sample (columns)}

\item{spikeins}{names of spike-ins, in same order as rownames of counts}

\item{spikein.lengths}{length of spike-ins (vector ordered accoring to "spikes")}

\item{spikein.labeling}{labeling status of spike-ins (vector ordered accoring to "spikes" consisting of "L" and "U")}

\item{samples}{individual name for each sample, e.g. colnames of count table}

\item{conditions.labeling}{labeling status of sample (vector consisting of "L" and "T")}

\item{paired}{is there for every labeled sample also a total sample and vice versa? only then sequencing depths can be estimated. Else they will be set to 1.}

\item{debug}{should debugging modus be used?}
}
\value{
list consisting of fitting-results in a data.frame and vector of fitted.counts
}
\description{
function to estimate normalization parameters based on spike-in counts
with GLM using offset length, seq depth per sample and cross-contamination control AND a spike-specific parameter to control for e.g.sequence bias
}
\examples{
data(spikein.counts)
spikeins = rownames(spikein.counts)
data(spikein.labeling)
data(spikein.lengths)
data(samples)
norm.res = spikein.normalization(spikein.counts, spikeins, spikein.lengths, spikein.labeling, 
	samples=colnames(spikein.counts), samples$conditions.labeling)
norm.res$sequencing.depth
norm.res$cross.contamination

}
\author{
Carina Demel
}

